*! THIS DO-FILE REPLICATES THE FOLLOWING PAPER IN QUANTITATIVE ECONOMICS:
*! "Child Work and Cognitive Development: Results from Four Low to Middle Income Countries"
*! BY MICHAEL KEANE, SONYA KRUTIKOVA, AND TIMOTHY NEAL
qui {
*! USER: SET PATH
global root "D:\Dropbox\YL time-allocation_priv\do\2017_18\Replication Package for Final Version"

*! CODE TO INSTALL PREREQUISITES
*! estpost & esttab:
*! net install st0085_2.pkg
*! xml_tab:
*! ssc install xml_tab
*! coefplot:
*! ssc install coefplot
*! lasso2:
*! net install st0594.pkg
*! ivreg2:
*! ssc install ivreg2

*! LOAD DATA
clear
set matsize 11000
set more off

global output "$root/output"
global ta_l			hsleep hchorecare htaskwork hschool hstudy	
global ta_s			hsleep hplay hchorecare htaskwork hstudy
global ta_st		hsleep hplay hchorecare htaskwork hschool
global lta_l		lhsleep lhchorecare lhtaskwork lhschool lhstudy	
global lta_s		lhsleep lhplay lhchorecare lhtaskwork lhstudy
global lta_st		lhsleep lhplay lhchorecare lhtaskwork lhschool
global ta_sql		hchorecaresq htaskworksq hschoolsq hstudysq
global ta_sqs		hchorecaresq htaskworksq hplaysq hstudysq
global ta_sqst		hchorecaresq htaskworksq hplaysq hschoolsq
use "$root/VA_data.dta", clear

***clean inr* vars for 
foreach i in 1 2 3 4 {
	recode inr`i' 1=0 if inr`i'==1 & dint==. & wi==. & hsleep==.
	}

***CONSTRUCT ADDITIONAL VARIABLES 
*numeric childid
	gen tempid=substr(childid, 3, 6)
	destring tempid, replace
	gen childid_num = .
	replace childid_num =(1*1000000)+tempid if country=="ET"
	replace childid_num =(2*1000000)+tempid if country=="IN"
	replace childid_num =(3*1000000)+tempid if country=="PE"
	replace childid_num =(4*1000000)+tempid if country=="VN"

*parents live in household
	gen dadinhh = dadlive==1
	gen mominhh = momlive==1
	gen bothinhh = momlive==1 & dadlive==1
*HAZ for OC R4: HAZ missing for the majority of the sample as too old for reference table. Therefore replacing haz with just height 
	replace zhfa = height_ocr4 if group==6 | group==12 | group==18 | group==24
*time allocation squared
	foreach i in hplay hchorecare htaskwork hschool hsleep lhplay lhchorecare lhtaskwork lhschool lhsleep {	
		gen `i'sq = `i'^2
	}
*time allocation using the scaled measures
	

*work indicator
	foreach i in taskwork chorecare {
		gen `i' = h`i'>0 & h`i'!=.
		gen l`i' = lh`i'>0 & lh`i'!=.
	}
	
*recode missing values and generate "missing" dummies for child ethnicity and religion
	*ethnicity
	recode chethnic_tab .=-999
	bys childid: egen tempethnic=max(chethnic_tab)
	replace chethnic_tab=tempethnic if chethnic_tab==-999
	recode chethnic_tab -999=.
	*religion
	recode chldrel_tab .=-999
	bys childid: egen temprel=max(chldrel_tab)
	replace chldrel_tab=temprel if chldrel_tab==-999
	recode chldrel_tab -999=.
*recode missing values and generate "missing" dummies for parental education and age
	*replace all missings within child with the highest non-missing
	foreach i in mom dad	{	
		*education
		recode `i'edu .=-999
		bys childid: egen temp`i'edu=max(`i'edu)
		replace `i'edu=temp`i'edu if `i'edu==-999
		*age
		recode `i'age .=-999
		bys childid: egen temp`i'age=max(`i'age)
		replace `i'age=temp`i'age if `i'age==-999
		}
		
	*for cases where parental education/age is missing in all round, replace with cohort, country, round mean
	gen momedu_miss=momedu==-999
	gen dadedu_miss=dadedu==-999
	gen momage_miss=momage==-999
	gen dadage_miss=dadage==-999

	foreach i in mom dad	{
		*education
		recode `i'edu -999=.
		bys group: egen `i'ed_mean=mean(`i'ed)
		replace `i'edu=0 if `i'ed_mean==0 &`i'edu==.
		replace `i'edu=1 if `i'ed_mean>0 &`i'ed_mean<9 & `i'edu==.
		replace `i'edu=2 if `i'ed_mean>8 &`i'ed_mean<13 & `i'edu==.
		replace `i'edu=3 if `i'ed_mean>12 & `i'edu==.
		*age
		recode `i'age -999=.
		bys group: egen `i'age_mean=mean(`i'age)
		replace `i'age = `i'age_mean if `i'age==.
		}
		*generate parental education dummies
	foreach i in mom dad	{
		gen `i'edu_none = `i'edu==0
		gen `i'edu_prim = `i'edu==1
		gen `i'edu_sec  = `i'edu==2
		gen `i'edu_psec = `i'edu==3
	}
	foreach i in none prim sec psec {
		replace momedu_`i'=. if momedu==.
		replace dadedu_`i'=. if dadedu==.
	}
	gen hstudysq = hstudy^2
	gen hschlstudysq = hschlstudy^2
	*gender interactions
		foreach i in hsleep hchorecare htaskwork hschool hstudy hplay hschlstudy{
	gen `i'Xmale = `i'*male
	}
	*pooling across countries within age - for va (including age 8) 
		gen group_ccva = .
		replace group_ccva=1 if group==2 | group==8 | group==14 | group==20
		replace group_ccva=2 if group==3 | group==9 | group==15 | group==21
		replace group_ccva=3 if group==5 | group==11 | group==17 | group==23
		replace group_ccva=4 if group==6 | group==12 | group==18 | group==24	
		label define group_ccva 1 "age 8" 2 "age 12" 3 "age 15" 4 "age 19"
		label values group_ccva group_ccva
	*pooling across countries within age - for fe
		gen group_cc = .
		replace group_cc=1 if group==3 | group==9 | group==15 | group==21
		replace group_cc=2 if group==5 | group==11 | group==17 | group==23
		replace group_cc=3 if group==6 | group==12 | group==18 | group==24
		label define group_cc 1 "age 12" 2 "age 15" 3 "age 19"
		label values group_cc group_cc
	*country specific cluster id's 
		gen clustid_country = .
		replace clustid_country = (1*100)+clustid if country=="ET"
		replace clustid_country = (2*100)+clustid if country=="IN"
		replace clustid_country = (3*100)+clustid if country=="PE"
		replace clustid_country = (4*100)+clustid if country=="VN"
	*pooling across ages within countries - for va	
		gen group_cava = .
		replace group_cava=1 if group==2 | group==3 | group==5 | group==6 
		replace group_cava=2 if group==8 | group==9 | group==11 | group==12
		replace group_cava=3 if group==14 | group==15 | group==17 | group==18 
		replace group_cava=4 if group==20 |group==21 | group==23 | group==24 
		label define group_cava 1 "Ethiopia" 2 "India" 3 "Peru" 4 "Vietnam"
		label values group_cava group_cava
	*pooling across ages within countries - for fe	
		gen group_ca = .
		replace group_ca=1 if group==3 | group==5 | group==6 
		replace group_ca=2 if group==9 | group==11 | group==12
		replace group_ca=3 if group==15 | group==17 | group==18 
		replace group_ca=4 if group==21 | group==23 | group==24 
		label define group_ca 1 "Ethiopia" 2 "India" 3 "Peru" 4 "Vietnam"
		label values group_ca group_ca
	*TA category interactions
		gen hschlstudyXhwork = hschlstudy*hwork
		gen hschlstudyXhplay = hschlstudy*hplay
		gen hworkXhplay		 = hwork*hplay
		gen hschlstudyXhsleep = hschlstudy*hsleep
		gen hschlstudyXhchorecare = hschlstudy*hchorecare
		gen hschlstudyXhtaskwork = hschlstudy*htaskwork
		gen hplayXhchorecare = hplay*hchorecare
		gen hplayXhtaskwork = hplay*htaskwork
		gen hworkXhsleep =  hwork*hsleep
		gen hplayXhsleep =  hplay*hsleep

***LABELS
label var hschool			"Hours/day in school"
label var hschoolsq			"Hours/day in school SQ"
label var hstudy			"Hours/day studying"
label var hstudysq			"Hours/day studying SQ"
label var hsleep			"Hours/day sleeping"
label var hsleepsq			"Hours/day sleeping squared"
label var hchorecare 		"Hours/day spent on hh chores"
label var hchorecaresq 		"Hours/day spent on hh chores SQ"
label var htaskwork 		"Hours/day spent on farm tasks/paid wrk"
label var htaskworksq 		"Hours/day spent on farm tasks/paid wrk SQ"
label var hschlstudy 		"Hours/day spent on school/study"
label var hschlstudysq 		"Hours/day spent on school/study SQ"
label var hplay				"Hours/day spent on leisure"
label var hplaysq				"Hours/day spent on leisure SQ"
label var lhsleep			"Lagged hours/day sleeping"
label var lhsleepsq			"Lagged hours/day sleeping squared"
label var lhchorecare 		"Lagged hours/day spent on hh chores"
label var lhtaskwork 		"Lagged hours/day spent on farm tasks/paid wrk"
label var lhschlstudy 		"Lagged hours/day spent on school/study"
label var lhplay			"Lagged hours/day spent on leisure"
label var l2hsleep			"Twice lagged hours/day sleeping"
label var l2hchorecare 		"Twice lagged hours/day spent on hh chores"
label var l2htaskwork 		"Twice lagged hours/day spent on farm tasks/paid wrk"
label var l2hschlstudy 		"Twice lagged hours/day spent on school/study"
label var l2hplay			"Twice lagged hours/day spent on leisure"
label var lquant_theta_eap 	"Lagged math score (IRT)"
label var lppvt_theta_eap 	"Lagged PPVT score (IRT)"
label var wi 			"Wealth index"
label var zhfa			"Height for age z-score"
label var bothinhh		"Both parents living in hh"
label var momedu_miss	"Mom education: missing"
label var dadedu_miss	"Dad education: missing"
label var momage_miss	"Mom age: missing"
label var dadage_miss	"Dad age: missing"
label var nsis			"No. sisters in hh"
label var nbroth		"No. brothers in hh"
label var ngparent		"No. grandparents in hh"
label var nopmadult		"No. other prime age adults in hh"
label var noelderly		"No. other elderly adults in hh"
foreach i in mom dad {
	label var `i'edu_prim	"`i' educ: primary"
	label var `i'edu_sec	"`i' educ: sec"
	label var `i'edu_psec	"`i' educ: post sec"
}

	
***GLOBALS

global chchars			agemon  male zhfa i.chldrel_tab i.chethnic_tab
global chchars_tv		zhfa
global chta				hsleep hchorecare htaskwork hschool hstudy
global chta_sch			hsleep hplay hchorecare htaskwork hstudy
global chta_schst		hsleep hplay hchorecare htaskwork 
global chta_study		hsleep hplay hchorecare htaskwork hschool
global chta_chores		hsleep hplay htaskwork hschool hstudy
global chta_studysq		hsleep hplay hchorecare htaskwork hschool hsleepsq hplaysq hchorecaresq htaskworksq hschoolsq
global lchta			lhsleep lhchorecare lhtaskwork lhschool lhstudy
global lchta_sch		lhsleep lhplay lhchorecare lhtaskwork lhstudy
global lchta_schst		lhsleep lhplay lhchorecare lhtaskwork
global lchta_study		lhsleep lhplay lhchorecare lhtaskwork lhschool
global lchta_chores		lhsleep lhplay lhtaskwork lhschool lhstudy
global l2chta			l2hsleep l2hchorecare l2htaskwork l2hschool l2hstudy
global l2chta_sch		l2hsleep l2hplay l2hchorecare l2htaskwork l2hstudy
global l2chta_schst		l2hsleep l2hplay l2hchorecare l2htaskwork
global l2chta_study		l2hsleep l2hplay l2hchorecare l2htaskwork l2hschool
global l2chta_chores	l2hsleep l2hplay l2htaskwork l2hschool l2hstudy
global chta_clonly  	hchorecare htaskwork
global lchta_clonly 	lhchorecare lhtaskwork
global parent			bothinhh momedu_prim momedu_sec momedu_psec momedu_miss momage momage_miss dadage dadage_miss dadedu_prim dadedu_sec dadedu_psec dadedu_miss 
global parent_tv			bothinhh
global hh  				urban wi nbroth nsis ngparent nopmadult noelderly  
global hh_tv			wi nbroth nsis ngparent nopmadult noelderly  
global chchars_f agemon male zhfa i.chldrel_tab i.chethnic_tab

*generate analysis sample = all controls non-missing
* math
reg quant_theta_eap	lquant_theta_eap $chchars $chta $lchta $parent $hh, cluster(clustid)
gen sample_math = e(sample)
* ppvt
reg ppvt_theta_eap	lppvt_theta_eap $chchars $chta $lchta $parent $hh, cluster(clustid)
gen sample_ppvt = e(sample)
*agency
reg zagencysubset	lzagencysubset $chchars $chta $lchta $parent $hh, cluster(clustid)
gen sample_agency = e(sample)
*replace sample_ppvt to zero if ethiopia and not amharic
replace sample_ppvt = 0 if (group==2 | group==3 | group==5) & lang==1

*generate change outcome measures
gen dquant_theta_eap=quant_theta_eap-lquant_theta_eap
gen dppvt_theta_eap =ppvt_theta_eap-lppvt_theta_eap

// changes to vars for outliers etc.
su zhfa if round == 4 & yc == 0
gen zhfa_fixed = (zhfa - r(mean))/r(sd) if round == 4 & yc == 0
su zhfa if round == 3 & yc == 0
replace zhfa_fixed = zhfa_fixed*r(sd) + r(mean) if round == 4 & yc == 0
replace zhfa_fixed = zhfa if missing(zhfa_fixed)
replace zhfa_fixed = 3 if zhfa_fixed > 3
replace zhfa_fixed = -4 if zhfa_fixed < -4
replace zhfa = zhfa_fixed
drop zhfa_fixed

gen flag_over16 = .
replace flag_over16 = 1 if htaskwork >= 16 | hchorecare >= 16 | hsleep >= 16 | hplay >= 16 | hstudy >= 16  | hschool >= 16
replace sample_math = 0 if flag_over16 == 1
replace sample_ppvt = 0 if flag_over16 == 1

//
// Tables 1, 2, and 3
// 

*descriptives sample = either in sample_ppvt or in sample_math
gen sample_desc = (sample_ppvt==1 | sample_math==1)
bys childid: egen sample_age=max(sample_desc)
*! TABLE 1
***Sample size at each round
***Math
matrix tableone = J(24,3,0)
gen temp_inr = inr3 + inr4
forvalues i = 1/24 {
	count  if group == `i' & sample_math == 1
	matrix tableone[`i',1] = r(N)
	count  if group == `i' & sample_ppvt == 1
	matrix tableone[`i',2] = r(N)
	count  if group == `i' & temp_inr >= 1
	matrix tableone[`i',3] = r(N)
}
noi display "Table 1: "
noi matlist tableone


//bys group: reg agemon male zhfa bothinhh momage dadage momedu_none momedu_prim momedu_sec momedu_psec dadedu_none dadedu_prim dadedu_sec dadedu_psec urban wi hhsize nbroth nsis ngparent nopmadult noelderly if group_desc!=. & sample_age==1

***Basic characteristics (for R2 only - "baseline")
//generate dummy ethnicity and religion vars
 xi i.chldrel_tab, prefix(d) noomit
 foreach i in 1 2 3 4 {
	gen chldrel_tab`i'= dchldrel_ta_`i'
	}
 xi i.chethnic_tab, prefix(d) noomit
 foreach i in 1 2 3 4 5 {
	gen chethnic_tab`i'=dchethnic_t_`i'
	}
	
 //"baseline" group indicator (R2 only)
gen group_desc = group if group==1 | group==4 | group==7 | group==10 | group==13 | group==16 | group==19 | group==22
label define groupdesc_label 1 "ET YC R2" 4 "ET OC R2" 7 "IN YC R2" 10 "IN OC R2" 13 "PE YC R2" 16 "PE OC R2" 19 "VN YC R2" 22 "VN OC R2"
label values group_desc groupdesc_label 

***Time allocation
gen hchorework = hchorecare+htaskwork
estpost tabstat hsleep hchorecare htaskwork hchorework hschool hstudy hplay if sample_desc==1, by(group) statistics(mean sd) listwise
esttab . using "$output/Table_2.csv", cells ("hsleep hchorecare htaskwork hchorework hschool hstudy hplay") sfmt(fmt %9.0g) plain noobs label  replace

***work detail
gen work_any		=chorecare==1 | taskwork==1
gen work_both		=chorecare==1 & taskwork==1 
gen hchorecare_work =hchorecare if chorecare==1
gen htaskwork_work  =htaskwork  if taskwork==1
gen hchorework_work =hchorework if (taskwork==1 | chorecare==1)

estpost tabstat work_any chorecare taskwork work_both if sample_desc==1, by(group) statistics(mean sd) listwise 
esttab . using "$output/Table_3_first4Cols.csv", cells ("work_any chorecare taskwork work_both hchorecare_work htaskwork_work") sfmt(fmt %9.0g) plain noobs label replace

****hours worked for those working any hours
tabstat hchorecare_work  if sample_desc==1, by(group) statistics(mean sd) save
	tabstatmat a
	mat x=a
tabstat htaskwork_work  if sample_desc==1, by(group) statistics(mean sd) save
	tabstatmat b
	mat y=b
tabstat hchorework_work  if sample_desc==1, by(group) statistics(mean sd) save
	tabstatmat c
	mat z=c
xml_tab x y z ,   save ($output\Table_3_last3Cols.xml) replace 

//
// Math Score VA Results
// 

matrix Fs_lagged = J(25,1,0)

gen temp_work_l = .
gen temp_work_s = .
gen temp_work_st = .
gen temp_work_all = .
gen temp_chores_l = .
gen temp_chores_s = .
gen temp_chores_st = .
gen temp_chores_all = .

foreach i in 2 3 5 6 8 9 11 12 14 15 17 18 20 21 23 24	{
	*********leisure*********
	xi: reg quant_theta_eap	lquant_theta_eap $chchars $ta_l $lta_l $parent $hh if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathl`i'
	replace temp_work_l = _b[htaskwork] in `i'/`i'
	replace temp_chores_l = _b[hchorecare] in `i'/`i'
	*********squared terms************
	xi: reg quant_theta_eap	lquant_theta_eap $chchars $ta_l $ta_sql $lta_l $parent $hh if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathlsq`i'
	*********schooling omitted*********
	xi: reg quant_theta_eap	lquant_theta_eap $chchars $ta_s $lta_s $parent $hh if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_maths`i'
	replace temp_work_s = _b[htaskwork] in `i'/`i'
	replace temp_chores_s = _b[hchorecare] in `i'/`i'
	test $lta_s 
	matrix Fs_lagged[`i',1] = r(p)
	*squared terms 
	xi: reg quant_theta_eap	lquant_theta_eap $chchars $ta_s $ta_sqs $lta_s $parent $hh if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathssq`i'
	*********study omitted*************
	xi: reg quant_theta_eap	lquant_theta_eap $chchars $ta_st $lta_st $parent $hh if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathst`i'
	replace temp_work_st = _b[htaskwork] in `i'/`i'
	replace temp_chores_st = _b[hchorecare] in `i'/`i'
	*squared terms
	xi: reg quant_theta_eap	lquant_theta_eap $chchars $ta_st $ta_sqst $lta_st $parent $hh if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathstsq`i'
	*building up the results
	xi: reg quant_theta_eap $ta_st if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathstnc`i'
	xi: reg quant_theta_eap	$chchars $ta_st $parent $hh if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathstbc`i'
	xi: reg quant_theta_eap	lquant_theta_eap $chchars $ta_st $lta_st $parent $hh if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathstbcl`i'
	
	********chores omitted********
	xi: reg quant_theta_eap	lquant_theta_eap $chchars $chta_chores $lchta_chores $parent $hh if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathch`i'
	*child labour controls only (time)
	xi: reg quant_theta_eap	lquant_theta_eap $chchars htaskwork hchorecare  lhtaskwork lhchorecare  $parent $hh if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathall`i'
	replace temp_work_all = _b[htaskwork] in `i'/`i'
	replace temp_chores_all = _b[hchorecare] in `i'/`i'
	*child labour controls only (dummies)	
	xi: reg quant_theta_eap	lquant_theta_eap $chchars taskwork chorecare ltaskwork lchorecare  $parent $hh if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathalld`i'
	}

su temp_work_l, detail
local med_workl = r(p50)
su temp_chores_l, detail
local med_choresl = r(p50)

su temp_work_s, detail
local med_works = r(p50)
su temp_chores_s, detail
local med_choress = r(p50)

su temp_work_st, detail
local med_workst = r(p50)
su temp_chores_st, detail
local med_choresst = r(p50)

su temp_work_all, detail
local med_workall = r(p50)
su temp_chores_all, detail
local med_choresall = r(p50)

foreach i in l {
	coefplot reg_math`i'2||reg_math`i'3||reg_math`i'5||reg_math`i'6||reg_math`i'8||reg_math`i'9||reg_math`i'11||reg_math`i'12||reg_math`i'14|| ///
	reg_math`i'15||reg_math`i'17||reg_math`i'18||reg_math`i'20||reg_math`i'21||reg_math`i'23||reg_math`i'24, vertical keep (hchorecare) mcolor(navy) msize(medlarge) ///
	ciopts(lcolor(navy) recast(rcap) lwidth(medthick)) levels(95) nokey bycoefs yline(0) /// yline(`med_choresl', lpattern(dash) lwidth(med) lcolor(black)) ///
	title("Leisure", size(huge)) ytitle("Standard deviations") ylabel(-0.2 -0.15 -0.1 -0.05 0 0.05) ///
	xlabel(1 "ET 8" 2 "ET 12" 3 "ET 15" 4 "ET 19" 5 "IN 8" 6 "IN 12" 7 "IN 15" 8 "IN 19" 9 "PE 8" 10 "PE 12" 11 "PE 15" 12 "PE 19" 13 "VN 8" 14 "VN 12" 15 "VN 15" 16 "VN 19" , angle(45) labsize(medsmall)) ///
	name(Coefplot_chores`i', replace)  graphregion(fcolor(white) lcolor(white)) nodraw

	coefplot reg_math`i'2||reg_math`i'3||reg_math`i'5||reg_math`i'6||reg_math`i'8||reg_math`i'9||reg_math`i'11||reg_math`i'12||reg_math`i'14|| ///
	reg_math`i'15||reg_math`i'17||reg_math`i'18||reg_math`i'20||reg_math`i'21||reg_math`i'23||reg_math`i'24, vertical keep (htaskwork) mcolor(navy) msize(medlarge) ///
	ciopts(lcolor(navy) recast(rcap) lwidth(medthick)) levels(95) bycoefs nokey yline(0)  /// yline(`med_workl', lpattern(dash) lwidth(med) lcolor(black)) ylabel(-0.2 -0.15 -0.1 -0.05 0 0.05) ///
	title("Market/Farm Work", size(huge)) ytitle("Standard deviations") ///
	xlabel(1 "ET 8" 2 "ET 12" 3 "ET 15" 4 "ET 19" 5 "IN 8" 6 "IN 12" 7 "IN 15" 8 "IN 19" 9 "PE 8" 10 "PE 12" 11 "PE 15" 12 "PE 19" 13 "VN 8" 14 "VN 12" 15 "VN 15" 16 "VN 19" , angle(45) labsize(medsmall)) ///
	name(Coefplot_econ`i', replace)  graphregion(fcolor(white) lcolor(white)) nodraw	
}
	
foreach i in  s st all {	
		coefplot reg_math`i'2||reg_math`i'3||reg_math`i'5||reg_math`i'6||reg_math`i'8||reg_math`i'9||reg_math`i'11||reg_math`i'12||reg_math`i'14|| ///
		reg_math`i'15||reg_math`i'17||reg_math`i'18||reg_math`i'20||reg_math`i'21||reg_math`i'23||reg_math`i'24, vertical keep (hchorecare) mcolor(navy) msize(medlarge) ///
		ciopts(lcolor(navy) recast(rcap) lwidth(medthick)) levels(95) bycoefs nokey yline(0) /// yline(`med_chores`i'', lpattern(dash) lwidth(med) lcolor(black)) ///
		title("Leisure", size(huge)) ytitle("Standard deviations") ///
		xlabel(1 "ET 8" 2 "ET 12" 3 "ET 15" 4 "ET 19" 5 "IN 8" 6 "IN 12" 7 "IN 15" 8 "IN 19" 9 "PE 8" 10 "PE 12" 11 "PE 15" 12 "PE 19" 13 "VN 8" 14 "VN 12" 15 "VN 15" 16 "VN 19" , angle(45) labsize(medsmall)) ///
		name(Coefplot_chores`i', replace)  graphregion(fcolor(white) lcolor(white)) nodraw

		coefplot reg_math`i'2||reg_math`i'3||reg_math`i'5||reg_math`i'6||reg_math`i'8||reg_math`i'9||reg_math`i'11||reg_math`i'12||reg_math`i'14|| ///
		reg_math`i'15||reg_math`i'17||reg_math`i'18||reg_math`i'20||reg_math`i'21||reg_math`i'23||reg_math`i'24, vertical keep (htaskwork) mcolor(navy) msize(medlarge) ///
		ciopts(lcolor(navy) recast(rcap) lwidth(medthick)) levels(95) bycoefs nokey yline(0) /// yline(`med_work`i'', lpattern(dash) lwidth(med) lcolor(black)) ///
		title("Market/Farm Work", size(huge)) ytitle("Standard deviations") ///
		xlabel(1 "ET 8" 2 "ET 12" 3 "ET 15" 4 "ET 19" 5 "IN 8" 6 "IN 12" 7 "IN 15" 8 "IN 19" 9 "PE 8" 10 "PE 12" 11 "PE 15" 12 "PE 19" 13 "VN 8" 14 "VN 12" 15 "VN 15" 16 "VN 19" , angle(45) labsize(medsmall)) ///
		name(Coefplot_econ`i', replace)  graphregion(fcolor(white) lcolor(white)) nodraw
}

//
// Figure 2
// 

		graph combine Coefplot_choresl Coefplot_econl, title("") ///
		ycommon graphregion(fcolor(white) lcolor(white)) nodraw name(fig5_L, replace)
		graph display fig5_L, ysize(2.5) xsize(5) scale(1.3)
		graph export "$output/Figure2_A.png", as(png)  replace

		graph combine Coefplot_choress Coefplot_econs, title("") ///
		ycommon graphregion(fcolor(white) lcolor(white)) nodraw name(fig5_S, replace)
		graph display fig5_S, ysize(2.5) xsize(5) scale(1.3)
		graph export "$output/Figure2_B.png", as(png)  replace
	
		graph combine Coefplot_choresst Coefplot_econst, title("") ///
		ycommon graphregion(fcolor(white) lcolor(white)) nodraw name(fig5_ST, replace)
		graph display fig5_ST, ysize(2.5) xsize(5) scale(1.3)
		graph export "$output/Figure2_C.png", as(png)  replace
		
//
// Figure 4 - A
// 
		graph combine Coefplot_choresall Coefplot_econall, title("") ///
		ycommon graphregion(fcolor(white) lcolor(white)) nodraw name(fig9_ALL, replace)
		graph display fig9_ALL, ysize(2.5) xsize(5) scale(1.3)
		graph export "$output/Figure4_A.png", as(png)  replace
		
//
// Figure 5
// 

global chta_alt		hsleep hchorecare htaskwork hschlstudy
global lchta_alt	lhsleep lhchorecare lhtaskwork lhschlstudy
global l2chta_alt	l2hsleep l2hchorecare l2htaskwork l2hschlstudy

gen temp_work_lalt = .
gen temp_work_schst = .
gen temp_chores_lalt = .
gen temp_chores_schst = .

*cases for which we have 2 lags
foreach i in  6 9 12 15 18 21 24 {
	*leisure omitted
	xi: reg dquant_theta_eap $chchars_tv $chta $lchta $l2chta $parent_tv $hh_tv if group==`i' & sample_math==1
	estimates store reg_dmathl`i'_2lags
	*schooling omitted
	xi: reg dquant_theta_eap $chchars_tv $chta_sch  $lchta_sch  $l2chta_sch $parent_tv $hh_tv if group==`i' & sample_math==1
	estimates store reg_dmaths`i'_2lags
	*study omitted
	xi: reg dquant_theta_eap $chchars_tv $chta_study $lchta_study $l2chta_study $parent_tv $hh_tv if group==`i' & sample_math==1
	estimates store reg_dmathst`i'_2lags
	*leisure omitted controlling for school-study combined
	xi: reg dquant_theta_eap $chchars_tv $chta_alt $lchta_alt $l2chta_alt $parent_tv $hh_tv if group==`i' & sample_math==1
	estimates store reg_dmathlalt`i'_2lags
	replace temp_work_lalt = _b[htaskwork] in `i'/`i'
	replace temp_chores_lalt = _b[hchorecare] in `i'/`i'
	*school and study omitted
	*VA
	xi: reg quant_theta_eap	lquant_theta_eap $chchars $chta_schst $lchta_schst $parent $hh  if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathschst`i'
	*FE
	xi: reg dquant_theta_eap $chchars_tv $chta_schst $lchta_schst $l2chta_schst $parent_tv $hh_tv if group==`i' & sample_math==1
	estimates store reg_dmathschst`i'_2lags
	replace temp_work_schst = _b[htaskwork] in `i'/`i'
	replace temp_chores_schst = _b[hchorecare] in `i'/`i'
	}
	
*cases for which we only have 1 lag (incl 12 year olds in Ethiopia for whom we get more observations if we include 1 lag)
foreach i in 3 5 11  17 23	{
	*leisure omitted
	xi: reg dquant_theta_eap $chchars_tv $chta $lchta $parent_tv $hh_tv if group==`i' & sample_math==1
	estimates store reg_dmathl`i'_lag
	replace temp_work_l = _b[htaskwork] in `i'/`i'
	replace temp_chores_l = _b[hchorecare] in `i'/`i'
	*schooling omitted
	xi: reg dquant_theta_eap $chchars_tv $chta_sch  $lchta_sch $parent_tv $hh_tv if group==`i' & sample_math==1
	estimates store reg_dmaths`i'_lag
	*study omitted
	xi: reg dquant_theta_eap $chchars_tv $chta_study $lchta_study $parent_tv $hh_tv if group==`i' & sample_math==1
	estimates store reg_dmathst`i'_lag
	*leisure omitted controlling for school-study combined
	xi: reg dquant_theta_eap $chchars_tv $chta_alt $lchta_alt $parent_tv $hh_tv if group==`i' & sample_math==1
	estimates store reg_dmathlalt`i'_lag
	replace temp_work_lalt = _b[htaskwork] in `i'/`i'
	replace temp_chores_lalt = _b[hchorecare] in `i'/`i'
	*school and study omitted
	*VA
	xi: reg quant_theta_eap	lquant_theta_eap $chchars $chta_schst $lchta_schst $parent $hh if group==`i' & sample_math==1, cluster(clustid)
	estimates store reg_mathschst`i'
	*FE
	xi: reg dquant_theta_eap $chchars_tv $chta_schst $lchta_schst $parent_tv $hh_tv if group==`i' & sample_math==1
	estimates store reg_dmathschst`i'_lag
	replace temp_work_schst = _b[htaskwork] in `i'/`i'
	replace temp_chores_schst = _b[hchorecare] in `i'/`i'
	}

su temp_work_lalt, detail
local med_worklalt = r(p50)
su temp_chores_lalt, detail
local med_choreslalt = r(p50)

su temp_work_schst, detail
local med_workschst= r(p50)
su temp_chores_schst, detail
local med_choresschst = r(p50)

foreach i in lalt schst {
		coefplot reg_dmath`i'3_lag||reg_dmath`i'5_lag||reg_dmath`i'6_2lags||reg_dmath`i'9_2lags||reg_dmath`i'11_lag||reg_dmath`i'12_2lags||reg_dmath`i'15_2lags||reg_dmath`i'17_lag ///
		||reg_dmath`i'18_2lags||reg_dmath`i'21_2lags||reg_dmath`i'23_lag||reg_dmath`i'24_2lags, vertical keep (hchorecare) mcolor(navy) msize(medlarge) ///
		ciopts(lcolor(navy) recast(rcap) lwidth(medthick)) levels(95)  bycoefs yline(0) /// yline(`med_chores`i'', lpattern(dash) lwidth(med) lcolor(black)) ///
		title("Leisure", size(huge)) ytitle("Standard deviations") nodraw ///
		xlabel(1 "ET 12" 2 "ET 15" 3 "ET 19" 4 "IN 12" 5 "IN 15" 6 "IN 19" 7 "PE 12" 8 "PE 15" 9 "PE 19" 10 "VN 12" 11 "VN 15" 12 "VN 19", angle(45) labsize(medsmall)) ///
		name(Coefplotfel_chores`i', replace)  graphregion(fcolor(white) lcolor(white))

		coefplot reg_dmath`i'3_lag||reg_dmath`i'5_lag||reg_dmath`i'6_2lags||reg_dmath`i'9_2lags||reg_dmath`i'11_lag||reg_dmath`i'12_2lags||reg_dmath`i'15_2lags||reg_dmath`i'17_lag ///
		||reg_dmath`i'18_2lags||reg_dmath`i'21_2lags||reg_dmath`i'23_lag||reg_dmath`i'24_2lags, vertical keep (htaskwork) mcolor(navy) msize(medlarge) ///
		ciopts(lcolor(navy) recast(rcap) lwidth(medthick)) levels(95) bycoefs yline(0) /// yline(`med_work`i'', lpattern(dash) lwidth(med) lcolor(black)) ///
		title("Market/Farm Work", size(huge)) ytitle("Standard deviations") nodraw ///
		xlabel(1 "ET 12" 2 "ET 15" 3 "ET 19" 4 "IN 12" 5 "IN 15" 6 "IN 19" 7 "PE 12" 8 "PE 15" 9 "PE 19" 10 "VN 12" 11 "VN 15" 12 "VN 19", angle(45) labsize(medsmall)) ///
		name(Coefplotfel_econ`i', replace)  graphregion(fcolor(white) lcolor(white))	
}



		graph combine Coefplotfel_choreslalt Coefplotfel_econlalt, title("") ///
		ycommon graphregion(fcolor(white) lcolor(white)) nodraw name(fig11_L, replace)
		graph display fig11_L, ysize(2.5) xsize(5) scale(1.3)
		graph export "$output/Figure5_A.png", as(png)  replace

		graph combine Coefplotfel_choresschst Coefplotfel_econschst, title("") ///
		ycommon graphregion(fcolor(white) lcolor(white)) nodraw name(fig11_S, replace)
		graph display fig11_S, ysize(2.5) xsize(5) scale(1.3)
		graph export "$output/Figure5_B.png", as(png)  replace

//
// Verbal Test Score Results
// 

estimates clear

replace temp_work_l = .
replace temp_work_s = .
replace temp_work_st = .
replace temp_work_all = .
replace temp_chores_l = .
replace temp_chores_s = .
replace temp_chores_st = .
replace temp_chores_all = .
matrix Fs_lagged = J(25,1,0)

qui foreach i in 2 3 5 8 9 11 14 15 17 20 21 23 {
	*leisure omitted
	xi: reg ppvt_theta_eap	lppvt_theta_eap $chchars $chta $lchta $parent $hh if group==`i' & sample_ppvt==1, cluster(clustid)
	estimates store reg_ppvtl`i'
	replace temp_work_l = _b[htaskwork] in `i'/`i'
	replace temp_chores_l = _b[hchorecare] in `i'/`i'
	*schooling omitted
	xi: reg ppvt_theta_eap	lppvt_theta_eap $chchars $chta_sch $lchta_sch $parent $hh if group==`i' & sample_ppvt==1, cluster(clustid)
	estimates store reg_ppvts`i'
	replace temp_work_s = _b[htaskwork] in `i'/`i'
	replace temp_chores_s = _b[hchorecare] in `i'/`i'
	test $lta_s 
	matrix Fs_lagged[`i',1] = r(p)
	*study omitted
	xi: reg ppvt_theta_eap	lppvt_theta_eap $chchars $chta_study $lchta_study $parent $hh if group==`i' & sample_ppvt==1, cluster(clustid)
	estimates store reg_ppvtst`i'
	replace temp_work_st = _b[htaskwork] in `i'/`i'
	replace temp_chores_st = _b[hchorecare] in `i'/`i'
	*study omitted with squared terms
	xi: reg ppvt_theta_eap	lppvt_theta_eap $chchars $chta_studysq $lchta_studysq $parent $hh if group==`i' & sample_ppvt==1, cluster(clustid)
	estimates store reg_ppvtstsq`i'
	*chores omitted
	xi: reg ppvt_theta_eap	lppvt_theta_eap $chchars $chta_chores $lchta_chores $parent $hh if group==`i' & sample_ppvt==1, cluster(clustid)
	estimates store reg_ppvtch`i'
	*child labour controls only (time)
	xi: reg ppvt_theta_eap	lppvt_theta_eap $chchars htaskwork hchorecare  lhtaskwork lhchorecare  $parent $hh if group==`i' & sample_ppvt==1, cluster(clustid)
	estimates store reg_ppvtall`i'
	replace temp_work_all = _b[htaskwork] in `i'/`i'
	replace temp_chores_all = _b[hchorecare] in `i'/`i'
	*child labour controls only (dummies)	
	xi: reg ppvt_theta_eap	lppvt_theta_eap $chchars taskwork chorecare ltaskwork lchorecare  $parent $hh if group==`i' & sample_ppvt==1, cluster(clustid)
	estimates store reg_ppvtalld`i'
	}

su temp_work_l, detail
local med_workl = r(p50)
su temp_chores_l, detail
local med_choresl = r(p50)

su temp_work_s, detail
local med_works = r(p50)
su temp_chores_s, detail
local med_choress = r(p50)

su temp_work_st, detail
local med_workst = r(p50)
su temp_chores_st, detail
local med_choresst = r(p50)

su temp_work_all, detail
local med_workall = r(p50)
su temp_chores_all, detail
local med_choresall = r(p50)

foreach i in l {	
		coefplot reg_ppvt`i'2||reg_ppvt`i'3||reg_ppvt`i'5||reg_ppvt`i'8||reg_ppvt`i'9||reg_ppvt`i'11||reg_ppvt`i'14|| ///
		reg_ppvt`i'15||reg_ppvt`i'17||reg_ppvt`i'20||reg_ppvt`i'21||reg_ppvt`i'23, vertical keep (hchorecare) mcolor(navy) msize(medlarge) ///
		ciopts(lcolor(navy) recast(rcap) lwidth(medthick)) levels(95)  bycoefs yline(0) /// yline(`med_choresl', lpattern(dash) lwidth(med) lcolor(black)) ///
		title("Leisure", size(huge)) ytitle("Standard deviations") nodraw ylabel(-0.4 -0.3 -0.2 -0.1 0 0.1 0.2) ///
		xlabel(1 "ET 8" 2 "ET 12" 3 "ET 15" 4 "IN 8" 5 "IN 12" 6 "IN 15" 7 "PE 8" 8 "PE 12" 9 "PE 15" 10 "VN 8" 11 "VN 12" 12 "VN 15", angle(45) labsize(medsmall)) ///
		name(Coefplot_chores`i', replace)  graphregion(fcolor(white) lcolor(white))
		
		coefplot reg_ppvt`i'2||reg_ppvt`i'3||reg_ppvt`i'5||reg_ppvt`i'8||reg_ppvt`i'9||reg_ppvt`i'11||reg_ppvt`i'14|| ///
		reg_ppvt`i'15||reg_ppvt`i'17||reg_ppvt`i'20||reg_ppvt`i'21||reg_ppvt`i'23, vertical keep (htaskwork) mcolor(navy) msize(medlarge) ///
		ciopts(lcolor(navy) recast(rcap) lwidth(medthick)) levels(95)  bycoefs yline(0) /// yline(`med_workl', lpattern(dash) lwidth(med) lcolor(black)) ///
		title("Market/Farm Work", size(huge)) ytitle("Standard deviations") nodraw ylabel(-0.4 -0.3 -0.2 -0.1 0 0.1 0.2) ///
		xlabel(1 "ET 8" 2 "ET 12" 3 "ET 15" 4 "IN 8" 5 "IN 12" 6 "IN 15" 7 "PE 8" 8 "PE 12" 9 "PE 15" 10 "VN 8" 11 "VN 12" 12 "VN 15", angle(45) labsize(medsmall)) ///
		name(Coefplot_econ`i', replace)  graphregion(fcolor(white) lcolor(white))	
}


foreach i in s st {	
		coefplot reg_ppvt`i'2||reg_ppvt`i'3||reg_ppvt`i'5||reg_ppvt`i'8||reg_ppvt`i'9||reg_ppvt`i'11||reg_ppvt`i'14|| ///
		reg_ppvt`i'15||reg_ppvt`i'17||reg_ppvt`i'20||reg_ppvt`i'21||reg_ppvt`i'23, vertical keep (hchorecare) mcolor(navy) msize(medlarge) ///
		ciopts(lcolor(navy) recast(rcap) lwidth(medthick)) levels(95) bycoefs yline(0) /// yline(`med_chores`i'', lpattern(dash) lwidth(med) lcolor(black)) ///
		title("Leisure", size(huge)) ytitle("Standard deviations") nodraw ylabel(-0.4 -0.3 -0.2 -0.1 0 0.1 0.2) ///
		xlabel(1 "ET 8" 2 "ET 12" 3 "ET 15" 4 "IN 8" 5 "IN 12" 6 "IN 15" 7 "PE 8" 8 "PE 12" 9 "PE 15" 10 "VN 8" 11 "VN 12" 12 "VN 15", angle(45) labsize(medsmall)) ///
		name(Coefplot_chores`i', replace)  graphregion(fcolor(white) lcolor(white))
		
		coefplot reg_ppvt`i'2||reg_ppvt`i'3||reg_ppvt`i'5||reg_ppvt`i'8||reg_ppvt`i'9||reg_ppvt`i'11||reg_ppvt`i'14|| ///
		reg_ppvt`i'15||reg_ppvt`i'17||reg_ppvt`i'20||reg_ppvt`i'21||reg_ppvt`i'23, vertical keep (htaskwork) mcolor(navy) msize(medlarge) ///
		ciopts(lcolor(navy) recast(rcap) lwidth(medthick)) levels(95) bycoefs yline(0) /// yline(`med_work`i'', lpattern(dash) lwidth(med) lcolor(black)) ///
		title("Market/Farm Work", size(huge)) ytitle("Standard deviations") nodraw ylabel(-0.4 -0.3 -0.2 -0.1 0 0.1 0.2) ///
		xlabel(1 "ET 8" 2 "ET 12" 3 "ET 15" 4 "IN 8" 5 "IN 12" 6 "IN 15" 7 "PE 8" 8 "PE 12" 9 "PE 15" 10 "VN 8" 11 "VN 12" 12 "VN 15", angle(45) labsize(medsmall)) ///
		name(Coefplot_econ`i', replace)  graphregion(fcolor(white) lcolor(white))	
}

foreach i in all {	
		coefplot reg_ppvt`i'2||reg_ppvt`i'3||reg_ppvt`i'5||reg_ppvt`i'8||reg_ppvt`i'9||reg_ppvt`i'11||reg_ppvt`i'14|| ///
		reg_ppvt`i'15||reg_ppvt`i'17||reg_ppvt`i'20||reg_ppvt`i'21||reg_ppvt`i'23, vertical keep (hchorecare) mcolor(navy) msize(medlarge) ///
		ciopts(lcolor(navy) recast(rcap) lwidth(medthick)) levels(95) bycoefs yline(0) /// yline(`med_chores`i'', lpattern(dash) lwidth(med) lcolor(black)) ///
		title("Leisure", size(huge)) ytitle("Standard deviations") nodraw ylabel(-0.3 -0.2 -0.1 0 0.1) ///
		xlabel(1 "ET 8" 2 "ET 12" 3 "ET 15" 4 "IN 8" 5 "IN 12" 6 "IN 15" 7 "PE 8" 8 "PE 12" 9 "PE 15" 10 "VN 8" 11 "VN 12" 12 "VN 15", angle(45) labsize(medsmall)) ///
		name(Coefplot_chores`i', replace)  graphregion(fcolor(white) lcolor(white))
		
		coefplot reg_ppvt`i'2||reg_ppvt`i'3||reg_ppvt`i'5||reg_ppvt`i'8||reg_ppvt`i'9||reg_ppvt`i'11||reg_ppvt`i'14|| ///
		reg_ppvt`i'15||reg_ppvt`i'17||reg_ppvt`i'20||reg_ppvt`i'21||reg_ppvt`i'23, vertical keep (htaskwork) mcolor(navy) msize(medlarge) ///
		ciopts(lcolor(navy) recast(rcap) lwidth(medthick)) levels(95) bycoefs yline(0) /// yline(`med_work`i'', lpattern(dash) lwidth(med) lcolor(black)) ///
		title("Market/Farm Work", size(huge)) ytitle("Standard deviations") nodraw ylabel(-0.3 -0.2 -0.1 0 0.1) ///
		xlabel(1 "ET 8" 2 "ET 12" 3 "ET 15" 4 "IN 8" 5 "IN 12" 6 "IN 15" 7 "PE 8" 8 "PE 12" 9 "PE 15" 10 "VN 8" 11 "VN 12" 12 "VN 15", angle(45) labsize(medsmall)) ///
		name(Coefplot_econ`i', replace)  graphregion(fcolor(white) lcolor(white))	
}

//
// Figure 3
// 


		graph combine Coefplot_choresl Coefplot_econl, title("") ///
		ycommon graphregion(fcolor(white) lcolor(white)) nodraw name(fig6_L, replace)
		graph display fig6_L, ysize(2.5) xsize(5) scale(1.3)
		graph export "$output/Figure3_A.png", as(png)  replace

		graph combine Coefplot_choress Coefplot_econs, title("") ///
		ycommon graphregion(fcolor(white) lcolor(white)) nodraw name(fig6_S, replace)
		graph display fig6_S, ysize(2.5) xsize(5) scale(1.3)
		graph export "$output/Figure3_B.png", as(png)  replace
	
		graph combine Coefplot_choresst Coefplot_econst, title("") ///
		ycommon graphregion(fcolor(white) lcolor(white)) nodraw name(fig6_ST, replace)
		graph display fig6_ST, ysize(2.5) xsize(5) scale(1.3)
		graph export "$output/Figure3_C.png", as(png)  replace

//
// Figure 4 - B
// 
		graph combine Coefplot_choresall Coefplot_econall, title("") ///
		ycommon graphregion(fcolor(white) lcolor(white)) nodraw name(fig9_ALL, replace)
		graph display fig9_ALL, ysize(2.5) xsize(5) scale(1.3)
		graph export "$output/Figure4_B.png", as(png)  replace


//
// Figure 12
// 

qui foreach i in 2 { 
		xi: reg quant_theta_eap lquant_theta_eap $chchars hsleep hplay c.hchorecare##c.hchorecare c.htaskwork##c.htaskwork $lchta_schst $parent $hh i.country if sample_math==1 & group_ccva==`i', cluster(clustid_country)
		margins, dydx(hchorecare) at(hchorecare=(0(1)8)) 
		marginsplot, recast(line) plotopts(lwidth(medthick) lcolor(navy)) ciopts(lwidth(medthick) lcolor(navy)) name(fig12_`i'_chores, replace) title("") xtitle("Hours") ytitle("Marginal Effect") nodraw graphregion(color(white)) title("Leisure", size(huge))
		margins, dydx(htaskwork) at(htaskwork=(0(1)8))
		marginsplot, recast(line) plotopts(lwidth(medthick) lcolor(navy)) ciopts(lwidth(medthick) lcolor(navy)) name(fig12_`i'_work, replace) title("") xtitle("Hours") ytitle("Marginal Effect") nodraw graphregion(color(white)) title("Market/Farm Work", size(huge))
}

qui foreach i in 2 { 
	xi: reg ppvt_theta_eap	lppvt_theta_eap $chchars hsleep hplay c.hchorecare##c.hchorecare c.htaskwork##c.htaskwork $lchta_schst $parent $hh i.country if sample_ppvt==1 & group_ccva==`i', cluster(clustid_country)
	margins, dydx(hchorecare) at(hchorecare=(0(1)8)) 
	marginsplot, recast(line) plotopts(lwidth(medthick) lcolor(navy)) ciopts(lwidth(medthick) lcolor(navy)) name(fig12_`i'_choresp, replace) title("") xtitle("Hours") ytitle("Marginal Effect") nodraw graphregion(color(white)) title("Leisure", size(huge))
	margins, dydx(htaskwork) at(htaskwork=(0(1)8))
	marginsplot, recast(line) plotopts(lwidth(medthick) lcolor(navy)) ciopts(lwidth(medthick) lcolor(navy)) name(fig12_`i'_workp, replace) title("") xtitle("Hours") ytitle("Marginal Effect") nodraw graphregion(color(white)) title("Market/Farm Work", size(huge))
}

graph combine fig12_2_chores fig12_2_work, ycommon graphregion(fcolor(white) lcolor(white)) title("") cols(2) nodraw name(fig12_math, replace)
		graph display fig12_math, ysize(3) xsize(5) scale(1.3)
		graph export "$output/Figure6.png", as(png)  replace
		
		
		
//
// Table 6
// 

// Fix ZHFA to be comparable and similarly distributed to Age 15

matrix Fs_1 = J(2,5,0)
matrix Fs_2 = J(2,5,0)

****1) FULLY POOLED
		xi: reg quant_theta_eap lquant_theta_eap $chchars_f $chta_study $lchta_study $parent $hh i.group_ccva i.group_cava i.clustid_country if sample_math==1  & group_cava!=., cluster(clustid_country)	
		estimates store regp_mathst
		test hchorecare = hplay
		matrix Fs_1[1,1] = r(F)
		matrix Fs_1[2,1] = r(p)
		test htaskwork = hplay
		matrix Fs_2[1,1] = r(F)
		matrix Fs_2[2,1] = r(p)

***3) COUNTRY SPECIFIC, POOLED ACROSS AGES
		
		foreach i in 1 2 3 4 {
		xi: reg quant_theta_eap lquant_theta_eap $chchars_f $chta_study $lchta_study $parent $hh i.group_ccva i.clustid_country if sample_math==1  & group_cava==`i', cluster(clustid_country)
		estimates store reg_mathstca`i'
		test hchorecare = hplay
		matrix Fs_1[1,`i'+1] = r(F)
		matrix Fs_1[2,`i'+1] = r(p)
		test htaskwork = hplay
		matrix Fs_2[1,`i'+1] = r(F)
		matrix Fs_2[2,`i'+1] = r(p)
		}
			
	xml_tab regp_mathst reg_mathstca1 reg_mathstca2 reg_mathstca3 reg_mathstca4 , replace stats(N) save("$output/Table6.xml") /*
		*/ title(Pooled VA - Geographic)/*
		*/ keep (hschool hchorecare htaskwork hplay)/*
		*/ format(SCLR3 NCLR3) stats(r2_a N) below sheet(Pooled VA geog)

noi display " "
noi display "F Statistics for Table 6 (chores = leisure): "
matrix rownames Fs_1 = Fstat pvalue	
matrix rownames Fs_2 = Fstat pvalue	
matrix colnames Fs_1 = Pooled Ethiopia India Peru Vietnam	
matrix colnames Fs_2 = Pooled Ethiopia India Peru Vietnam	
noi matlist Fs_1
noi display " "
noi display "F Statistics for Table 6 (work = leisure): "
noi matlist Fs_2

//
// Table 7
// 

matrix Fs2_1 = J(2,6,0)
matrix Fs2_2 = J(2,6,0)

		foreach i in 1 2 3 4 {
		*study omitted
		xi: reg quant_theta_eap lquant_theta_eap $chchars $chta_study $lchta_study $parent $hh i.country i.clustid_country if sample_math==1  & group_ccva==`i', cluster(clustid_country)
		estimates store reg_mathstcc`i'
		test hchorecare = hplay
		matrix Fs2_1[1,`i'] = r(F)
		matrix Fs2_1[2,`i'] = r(p)
		test htaskwork = hplay
		matrix Fs2_2[1,`i'] = r(F)
		matrix Fs2_2[2,`i'] = r(p)
		}
			
		foreach i in 0 1 {
		*study omitted
		xi: reg quant_theta_eap lquant_theta_eap $chchars $chta_study $lchta_study $parent $hh i.country i.clustid_country if sample_math==1  & group_cava!=. & male==`i' , cluster(clustid_country)	
		estimates store reg_mathstsex`i'
		test hchorecare = hplay
		matrix Fs2_1[1,`i'+5] = r(F)
		matrix Fs2_1[2,`i'+5] = r(p)
		test htaskwork = hplay
		matrix Fs2_2[1,`i'+5] = r(F)
		matrix Fs2_2[2,`i'+5] = r(p)
		}
		xml_tab reg_mathstcc1 reg_mathstcc2 reg_mathstcc3 reg_mathstcc4 reg_mathstsex0 reg_mathstsex1, replace stats(N) save("$output/Table7.xml") /*
		*/ title(Pooled VA - Child Chars)/*
		*/ keep (hschool hchorecare htaskwork hplay)/*
		*/ format(SCLR3 NCLR3) stats(r2_a N) below sheet(Pooled VA child)

noi display " "
noi display "F Statistics for Table 7 (chores = leisure): "
matrix rownames Fs2_1 = Fstat pvalue	
matrix rownames Fs2_2 = Fstat pvalue	
matrix colnames Fs2_1 = Age8 Age12 Age15 Age19 Female Male	
matrix colnames Fs2_2 = Age8 Age12 Age15 Age19 Female Male	
noi matlist Fs2_1
noi display " "
noi display "F Statistics for Table 7 (work = leisure): "
noi matlist Fs2_2

estimates clear

//	
// Figure 1
//

gen age = 8 if group == 2 | group == 8 | group == 14 | group == 20 
replace age = 12 if group == 3 | group == 9 | group == 15 | group == 21 
replace age = 15 if group == 5 | group == 11 | group == 17 | group == 23 
replace age = 19 if group == 6 | group == 12 | group == 18 | group == 24 
tabulate group if sample_math == 1, generate(dum)
set more off

drop dum16
gen work_2 = htaskwork + 0.01
gen chores_2 = hchorecare + 0.01

// Create synthetic data with what we want for predictions
local oldN = _N
local expand = `oldN' + 1000
set obs `expand'
local start = `expand' - 1000
gen temp_graph = 0.01*(_n-`oldN') in `start'/`expand'

local varlist = "wi urban nbroth nsis dadedu_prim dadedu_sec dadedu_psec momedu_prim momedu_sec momedu_psec male dum1 dum2 dum3 dum4 dum5 dum6 dum7 dum8 dum9 dum10 dum11 dum12 dum13 dum14 dum15"
qui foreach x in `varlist' {
	su `x' if sample_math == 1
	replace `x' = r(mean) if !missing(temp_graph)
}
replace sample_math = 1 if !missing(temp_graph)
replace hschool = 0 if !missing(temp_graph)

// Estimate Model
mfp: regress hschool work_2 chores_2 (wi urban nbroth nsis dadedu_prim dadedu_sec dadedu_psec momedu_prim momedu_sec momedu_psec male dum*) if sample_math == 1 & htaskwork < 10 & hchorecare < 10

// Work varies Leisure constant
replace Iwork__1 = temp_graph^3-.766597165 if !missing(temp_graph)
replace Iwork__2 = temp_graph^3*ln(temp_graph)+.0679189307 if !missing(temp_graph)
replace Ichor__1 = (0.01^(-2))-.3583023876 if !missing(temp_graph)
replace Ichor__2  = 0.01^2-2.7909387  if !missing(temp_graph)

predict yhat_workvar if !missing(temp_graph), xb
predict yhat_workstd if !missing(temp_graph), stdp
gen yhat_worklow = yhat_workvar - 1.96*yhat_workstd if !missing(temp_graph)
gen yhat_workhigh = yhat_workvar + 1.96*yhat_workstd if !missing(temp_graph)


// Leisure varies Work constant
replace Iwork__1 = 0.01^(3)-.766597165 if !missing(temp_graph)
replace Iwork__2 = 0.01^(3)*ln(0.01)+.0679189307 if !missing(temp_graph)
replace Ichor__1 = (temp_graph^(-2))-.3583023876  if !missing(temp_graph)
replace Ichor__2  = temp_graph^(2)-2.7909387 if !missing(temp_graph)

predict yhat_chorevar if !missing(temp_graph), xb
predict yhat_chorestd if !missing(temp_graph), stdp
gen yhat_chorelow = yhat_chorevar - 1.96*yhat_chorestd if !missing(temp_graph)
gen yhat_chorehigh = yhat_chorevar + 1.96*yhat_chorestd if !missing(temp_graph)

twoway rarea yhat_worklow yhat_workhigh temp_graph if !missing(temp_graph) & temp_graph < 9, fcolor(gs12) lcolor(gs12)  lwidth(none) fintensity(100) ///
|| rarea yhat_chorelow yhat_chorehigh temp_graph if !missing(temp_graph) & temp_graph < 9, fcolor(gs12) lcolor(gs12)  lwidth(none) fintensity(100)  ///
|| line yhat_workvar yhat_chorevar temp_graph if !missing(temp_graph) & temp_graph < 9, lcolor(black black) lwidth(medthick medthick) lpattern(solid dash) ///
name(poly, replace) graphregion(color(white))  ytitle("School Hours") xtitle("Work or Chore Hours") ///
legend(order(3 4) label(3 "Market/Farm Work") label(4 "Domestic Leisure") bmargin(none) pos(8) ring(0)) ylabel(0 2 4 6) xlabel(1 3 5 7 9) nodraw
graph display poly, ysize(2.5) xsize(4) scale(1.3)
graph export "$output/Figure1.png", as(png)  replace

		
// Load IV Data
use "$root/IV_data.dta", clear
		
// LASSO
set more off
local rainfall_inst = "dmrain_spec_2mo_dm dmrain_spec_12mo_dm"	
local controls = "agemon male zhfa i.chldrel_tab i.chethnic_tab bothinhh momedu_prim momedu_sec momedu_psec momedu_miss momage momage_miss dadage dadage_miss dadedu_prim dadedu_sec dadedu_psec dadedu_miss urban wi nbroth nsis ngparent nopmadult noelderly"
local controls_lasso_nolag = "agemon male zhfa i.chldrel_tab i.chethnic_tab bothinhh momedu_prim momedu_sec momedu_psec momedu_miss momage momage_miss dadage dadage_miss dadedu_prim dadedu_sec dadedu_psec dadedu_miss urban wi nbroth nsis ngparent nopmadult noelderly"
local controls_lasso_lag = "lquant_theta_eap agemon male zhfa i.chldrel_tab i.chethnic_tab bothinhh momedu_prim momedu_sec momedu_psec momedu_miss momage momage_miss dadage dadage_miss dadedu_prim dadedu_sec dadedu_psec dadedu_miss urban wi nbroth nsis ngparent nopmadult noelderly"

local v = 0
local grouplist = "2 3"
local sampvar = "math"

forvalues k = 1/2 {
qui foreach g in `grouplist' {
	noi display "g: `g'"
	if (`g' == 2 | `g' == 5 | `g' == 8 | `g' == 11 | `g' == 14 | `g' == 17 | `g' == 20 | `g' == 23) local r = 3
	else local r = 4
	
	if (`g' == 2) local rainintlist = "c.male c.wi c.urban c.timesch2 c.live_prices c.shenv4 c.older_siblings c.nbroth c.nsis c.agri_prices c.m1 c.m10 c.m11 c.m12"
	if (`g' == 3) local rainintlist = "c.male c.wi c.urban c.timesch2 c.live_prices c.shenv4 c.older_siblings c.nbroth c.nsis c.agri_prices c.m1 c.m2 c.m10 c.m11 c.m12"
	if (`g' == 2) local instruments_ET = "agri_prices live_prices c.agri_prices#c.male c.live_prices#c.male timesch2 shenv4 father_agriculture c.m1 c.m10 c.m11 c.m12"		
	if (`g' == 3) local instruments_ET = "agri_prices live_prices c.agri_prices#c.male c.live_prices#c.male timesch2 shenv4 father_agriculture c.m1 c.m2 c.m10 c.m11 c.m12"		

	local varlist = "rain_spec_2mo_dm rain_spec_12mo_dm factorwage`r'_ET1 factorwage`r'_ET2 factorprice`r'_ET1 factorprice`r'_ET2 factorserv`r'_ET1 factorserv`r'_ET2"
	foreach x in `varlist' {
		su `x' if group == `g'
		gen dm`x' = `x' - r(mean) if group == `g'
	}

	local factorlist_r`r' = "dmfactorwage`r'_ET1 dmfactorwage`r'_ET2 dmfactorprice`r'_ET1 dmfactorprice`r'_ET2 dmfactorserv`r'_ET1 dmfactorserv`r'_ET2"
	local instlist = "`instruments_ET' `rainfall_inst' c.(`rainfall_inst')#(`rainintlist') `factorlist_r`r''  (c.(`factorlist_r`r''))#(`rainintlist')"
	
	if (`g' == 2) local lcount = 25
	if (`g' == 3) local lcount = 500
	local samplez = 1
	
	if (`k' == 1 | `g' == 2) {
		gen temp_sample1 = 0
		replace temp_sample1 = 1 if group == `g'
		gen temp_sample2 = 0
		replace temp_sample2 = 1 if group == `g'
	}
	if (`k' == 2 & `g' == 3) {
		ivreg2 ppvt_theta_eap `controls' (htaskwork hchorecare hplay hsleep = `instlist') if group == `g', first robust
		gen temp_sample1 = e(sample)
		ivreg2 ppvt_theta_eap lppvt_theta_eap `controls' (htaskwork hchorecare hplay hsleep = `instlist') if group == `g', first robust
		gen temp_sample2 = e(sample)
		replace temp_sample2 = 1 if group == `g'
	}
	
	// LASSO PICKS (No lag)
	lasso2 htaskwork `instlist' `controls_lasso_nolag' if temp_sample1, ols postres lic(bic) lcount(`lcount') partial(`controls_lasso_nolag')
	local inst = e(selected)
	if ("`inst'" != ".") local inst_work = e(selected)
	if ("`inst'" == ".") local inst_work = "" 
	noi display e(selected)
	lasso2 hchorecare `instlist' `inst_work' `controls_lasso_nolag' if temp_sample1, ols postres lic(bic) lcount(`lcount') partial(`inst_work' `controls_lasso_nolag')
	local inst = e(selected)
	if ("`inst'" != ".") local inst_chore = e(selected)
	if ("`inst'" == ".") local inst_chore = "" 
	noi display e(selected)
	lasso2 hplay `instlist' `inst_work' `inst_chore' `controls_lasso_nolag' if temp_sample1, ols postres lic(bic) lcount(`lcount') partial(`inst_work' `inst_chore' `controls_lasso_nolag')
	local inst = e(selected)
	if ("`inst'" != ".") local inst_play = e(selected)
	if ("`inst'" == ".") local inst_play = ""
	noi display e(selected)		
	lasso2 hsleep `instlist' `inst_work' `inst_chore' `inst_play' `controls_lasso_nolag' if temp_sample1, ols postres lic(bic) lcount(`lcount') partial(`inst_work' `inst_chore' `inst_play' `controls_lasso_nolag')
	local inst = e(selected)
	if ("`inst'" != ".") local inst_sleep = e(selected)
	if ("`inst'" == ".") local inst_sleep = ""
	noi display e(selected)					
	local inst_list_bic_nolag_`k'_`g' = "`inst_work' `inst_chore' `inst_play' `inst_sleep'"

	
	// LASSO PICKS (lag)
	lasso2 htaskwork `instlist' `controls_lasso_lag' if temp_sample2, ols postres lic(bic) lcount(`lcount') partial(`controls_lasso_lag')
	local inst = e(selected)
	if ("`inst'" != ".") local inst_work = e(selected)
	if ("`inst'" == ".") local inst_work = "" 
	noi display e(selected)
	lasso2 hchorecare `instlist' `inst_work' `controls_lasso_lag' if temp_sample2, ols postres lic(bic) lcount(`lcount') partial(`inst_work' `controls_lasso_lag')
	local inst = e(selected)
	if ("`inst'" != ".") local inst_chore = e(selected)
	if ("`inst'" == ".") local inst_chore = "" 
	noi display e(selected)
	lasso2 hplay `instlist' `inst_work' `inst_chore' `controls_lasso_lag' if temp_sample2, ols postres lic(bic) lcount(`lcount') partial(`inst_work' `inst_chore' `controls_lasso_lag')
	local inst = e(selected)
	if ("`inst'" != ".") local inst_play = e(selected)
	if ("`inst'" == ".") local inst_play = ""
	noi display e(selected)		
	lasso2 hsleep `instlist' `inst_work' `inst_chore' `inst_play' `controls_lasso_lag' if temp_sample2, ols postres lic(bic) lcount(`lcount') partial(`inst_work' `inst_chore' `inst_play' `controls_lasso_lag')
	local inst = e(selected)
	if ("`inst'" != ".") local inst_sleep = e(selected)
	if ("`inst'" == ".") local inst_sleep = ""
	noi display e(selected)					
	local inst_list_bic_lag_`k'_`g' = "`inst_work' `inst_chore' `inst_play' `inst_sleep'"

	local v = `v' + 1
	drop dm* temp_samp*
}
}
// Remove outliers from zhfa and 
su zhfa if round == 4 & yc == 0
gen zhfa_fixed = (zhfa - r(mean))/r(sd) if round == 4 & yc == 0
su zhfa if round == 3 & yc == 0
replace zhfa_fixed = zhfa_fixed*r(sd) + r(mean) if round == 4 & yc == 0
replace zhfa_fixed = zhfa if missing(zhfa_fixed)
replace zhfa_fixed = 3 if zhfa_fixed > 3
replace zhfa_fixed = -4 if zhfa_fixed < -4
replace zhfa = zhfa_fixed
drop zhfa_fixed

// IV Results
set more off
noi display "Math 8 nolag:"
noi display "`inst_list_bic_nolag_1_2'"
noi display "Math 8 lag:"
noi display "`inst_list_bic_lag_1_2'"

noi display "Math 12 nolag:"
noi display "`inst_list_bic_nolag_1_3'"
noi display "Math 12 lag:"
noi display "`inst_list_bic_lag_1_3'"

noi display "Verbal 8 nolag:"
noi display "`inst_list_bic_nolag_2_2'"
noi display "Verbal 8 lag:"
noi display "`inst_list_bic_lag_2_2'"

noi display "Verbal 12 nolag:"
noi display "`inst_list_bic_nolag_2_3'"
noi display "Verbal 12 lag:"
noi display "`inst_list_bic_lag_2_3'"

matrix results_N = J(15,4,0)
matrix results_1 = J(27,9,0)
matrix results_2 = J(27,9,0)
forvalues k = 1/2 {
local rainfall_inst = "dmrain_spec_2mo_dm dmrain_spec_12mo_dm"	
local controls = "agemon male zhfa i.chldrel_tab i.chethnic_tab bothinhh momedu_prim momedu_sec momedu_psec momedu_miss momage momage_miss dadage dadage_miss dadedu_prim dadedu_sec dadedu_psec dadedu_miss urban wi nbroth nsis ngparent nopmadult noelderly"
local controls_lasso_nolag = "agemon male zhfa i.chldrel_tab i.chethnic_tab bothinhh momedu_prim momedu_sec momedu_psec momedu_miss momage momage_miss dadage dadage_miss dadedu_prim dadedu_sec dadedu_psec dadedu_miss urban wi nbroth nsis ngparent nopmadult noelderly"
local controls_lasso_lag = "lquant_theta_eap agemon male zhfa i.chldrel_tab i.chethnic_tab bothinhh momedu_prim momedu_sec momedu_psec momedu_miss momage momage_miss dadage dadage_miss dadedu_prim dadedu_sec dadedu_psec dadedu_miss urban wi nbroth nsis ngparent nopmadult noelderly"

local v = 0
local grouplist = "2 3"
if (`k' == 1) local depvar = "quant_theta_eap"
if (`k' == 2) local depvar = "ppvt_theta_eap"
if (`k' == 1) local sampvar = "math"
if (`k' == 2) local sampvar = "ppvt"
foreach g in `grouplist' {
	noi display "g: `g'"
	if (`g' == 2 | `g' == 5 | `g' == 8 | `g' == 11 | `g' == 14 | `g' == 17 | `g' == 20 | `g' == 23) local r = 3
	else local r = 4
	
	if (`g' == 2) local rainintlist = "c.male c.wi c.urban c.timesch2 c.live_prices c.shenv4 c.older_siblings c.nbroth c.nsis c.agri_prices c.m1 c.m10 c.m11 c.m12"
	if (`g' == 3) local rainintlist = "c.male c.wi c.urban c.timesch2 c.live_prices c.shenv4 c.older_siblings c.nbroth c.nsis c.agri_prices c.m1 c.m2 c.m10 c.m11 c.m12"
	if (`g' == 2) local instruments_ET = "agri_prices live_prices c.agri_prices#c.male c.live_prices#c.male timesch2 shenv4 father_agriculture c.m1 c.m10 c.m11 c.m12"		
	if (`g' == 3) local instruments_ET = "agri_prices live_prices c.agri_prices#c.male c.live_prices#c.male timesch2 shenv4 father_agriculture c.m1 c.m2 c.m10 c.m11 c.m12"		

	local varlist = "rain_spec_2mo_dm rain_spec_12mo_dm factorwage`r'_ET1 factorwage`r'_ET2 factorprice`r'_ET1 factorprice`r'_ET2 factorserv`r'_ET1 factorserv`r'_ET2"
	foreach x in `varlist' {
		su `x' if group == `g'
		gen dm`x' = `x' - r(mean) if group == `g'
	}

	local factorlist_r`r' = "dmfactorwage`r'_ET1 dmfactorwage`r'_ET2 dmfactorprice`r'_ET1 dmfactorprice`r'_ET2 dmfactorserv`r'_ET1 dmfactorserv`r'_ET2"
	local instlist = "`instruments_ET' `rainfall_inst' c.(`rainfall_inst')#(`rainintlist') `factorlist_r`r''  (c.(`factorlist_r`r''))#(`rainintlist')"
	
	// OLS (No Controls)
	reg `depvar' htaskwork hchorecare hplay hsleep if group == `g', 
	matrix results_`k'[1+`v'*15,1] = _b[htaskwork]
	matrix results_`k'[2+`v'*15,1] = _se[htaskwork]
	matrix results_`k'[5+`v'*15,1] = _b[hchorecare]
	matrix results_`k'[6+`v'*15,1] = _se[hchorecare]
	matrix results_`k'[9+`v'*15,1] = _b[hplay]
	matrix results_`k'[10+`v'*15,1] = _se[hplay]
	matrix results_N[2,(`g'-1)+(2*(`k'-1))] = e(N)
	// OLS
	reg `depvar' htaskwork hchorecare hplay hsleep `controls' if group == `g', 
	matrix results_`k'[1+`v'*15,2] = _b[htaskwork]
	matrix results_`k'[2+`v'*15,2] = _se[htaskwork]
	matrix results_`k'[5+`v'*15,2] = _b[hchorecare]
	matrix results_`k'[6+`v'*15,2] = _se[hchorecare]
	matrix results_`k'[9+`v'*15,2] = _b[hplay]
	matrix results_`k'[10+`v'*15,2] = _se[hplay]
	matrix results_N[3,(`g'-1)+(2*(`k'-1))] = e(N)

	// VA
	reg `depvar' l`depvar' htaskwork hchorecare hplay hsleep lhtaskwork lhchorecare lhplay lhsleep `controls' if group == `g', cluster(clustid)
	matrix results_`k'[1+`v'*15,3] = _b[htaskwork]
	matrix results_`k'[2+`v'*15,3] = _se[htaskwork]
	matrix results_`k'[5+`v'*15,3] = _b[hchorecare]
	matrix results_`k'[6+`v'*15,3] = _se[hchorecare]
	matrix results_`k'[9+`v'*15,3] = _b[hplay]
	matrix results_`k'[10+`v'*15,3] = _se[hplay]
	matrix results_N[4,(`g'-1)+(2*(`k'-1))] = e(N)

	// IV Regressions
	local estlist = "ivlasso_full ivlasso_bic gmmlasso_bic"
	local i = 4
	foreach e in `estlist' {
		forvalues b = 1/2 {
			if (`b' == 1) local lagterm = ""
			else local lagterm = "l`depvar'"
			if (`b' == 1) local instterm = "`inst_list_bic_nolag_`k'_`g''"
			else local instterm = "`inst_list_bic_lag_`k'_`g''"
			
			if ("`e'" == "ivlasso_bic") ivreg2 `depvar' `lagterm' `controls' (htaskwork hchorecare hplay hsleep = `instterm') if group == `g', first robust
			else if ("`e'" == "gmmlasso_bic") ivreg2 `depvar' `lagterm' `controls' (htaskwork hchorecare hplay hsleep = `instterm') if group == `g', first gmm2s robust
			else if ("`e'" == "ivlasso_full") ivreg2 `depvar' `lagterm' `controls' (htaskwork hchorecare hplay hsleep = `instlist') if group == `g', robust first
			
			matrix res = e(first)
			matrix results_`k'[1+`v'*15,`i'+(`b'-1)*3] = _b[htaskwork]
			matrix results_`k'[2+`v'*15,`i'+(`b'-1)*3] = _se[htaskwork]
			matrix results_`k'[3+`v'*15,`i'+(`b'-1)*3] = res[8,1]	
			matrix results_`k'[5+`v'*15,`i'+(`b'-1)*3] = _b[hchorecare]
			matrix results_`k'[6+`v'*15,`i'+(`b'-1)*3] = _se[hchorecare]
			matrix results_`k'[7+`v'*15,`i'+(`b'-1)*3] = res[8,2]
			matrix results_`k'[9+`v'*15,`i'+(`b'-1)*3] = _b[hplay]
			matrix results_`k'[10+`v'*15,`i'+(`b'-1)*3] = _se[hplay]
			matrix results_`k'[11+`v'*15,`i'+(`b'-1)*3] = res[8,3]
			matrix results_`k'[12+`v'*15,`i'+(`b'-1)*3] = e(exexog_ct)
			
			if ("`e'" == "ivlasso_bic") local jump = 2
			else if ("`e'" == "gmmlasso_bic") local jump = 3
			else if ("`e'" == "ivlasso_full") local jump = 1
			
			matrix results_N[6+(`b'-1)*5+`jump',(`g'-1)+(2*(`k'-1))] = e(N)
		}
		local i = `i' + 1
	}
	local v = `v' + 1
	drop dm*
}
}

//
// Table 4 & 5
//

matrix colnames results_1 = OLS_NC OLS VA TSLS_All TSLS_LASSO GMM_LASSO TSLS_LT_ALL TSLS_LT_LASSO GMM_LT_LASSO
matrix colnames results_2 = OLS_NC OLS VA TSLS_All TSLS_LASSO GMM_LASSO TSLS_LT_ALL TSLS_LT_LASSO GMM_LT_LASSO
matrix rownames results_1 = Work_Beta Work_STDERR Work_F NA Leisure_Beta Leisure_STDERR Leisure_F NA Leisure_Beta Leisure_STDERR Leisure_F Instruments NA NA NA Work_Beta Work_STDERR Work_F NA Leisure_Beta Leisure_STDERR Leisure_F NA Leisure_Beta Leisure_STDERR Leisure_F Instruments
matrix rownames results_2 = Work_Beta Work_STDERR Work_F NA Leisure_Beta Leisure_STDERR Leisure_F NA Leisure_Beta Leisure_STDERR Leisure_F Instruments NA NA NA Work_Beta Work_STDERR Work_F NA Leisure_Beta Leisure_STDERR Leisure_F NA Leisure_Beta Leisure_STDERR Leisure_F Instruments
noi display " "
noi display "Table 4: IV Results for Maths Scores"
noi matlist results_1
noi display " "
noi display "Table 5: IV Results for Verbal Scores"
noi matlist results_2
}
